==> global-4.8.2.tar.gz: global-4.8.2/libutil/conf.h <==
/*
 * Copyright (c) 1998, 1999 Shigio Yamaguchi
 * Copyright (c) 1999, 2000, 2001, 2002, 2003 Tama Communications Corporation
 *
 * This file is part of GNU GLOBAL.
 *
 * GNU GLOBAL is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * GNU GLOBAL is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef _CONF_H_
#define _CONF_H_

#include "strbuf.h"
/*
 * Access library for gtags.conf (.globalrc).
 * File format is a subset of XXXcap (termcap, printcap) file.
 */
#define GTAGSCONF       "/etc/gtags.conf"
#define OLD_GTAGSCONF   "/etc/global.conf"	/* for compatibility */
#define DEBIANCONF      "/etc/gtags/gtags.conf"
#define OLD_DEBIANCONF  "/etc/gtags/global.conf"/* for compatibility */
#define GTAGSRC 	".globalrc"
#ifdef __DJGPP__
#define DOS_GTAGSRC	"_globalrc"
#endif
#define DEFAULTLABEL    "default"
#define DEFAULTSUFFIXES "c,h,y,c++,cc,cpp,cxx,hxx,hpp,C,H,s,S,java,php,php3,phtml"
#define DEFAULTSKIP	"GPATH,GTAGS,GRTAGS,GSYMS,HTML/,tags,TAGS,ID,y.tab.c,y.tab.h,.notfunction,cscope.out,.gdbinit,SCCS/,RCS/,CVS/,CVSROOT/,{arch}/,.svn/,.cvsrc,.cvsignore,.cvspass,.cvswrappers,.deps/,autom4te.cache/,.snprj/"

void openconf(void);
int getconfn(const char *, int *);
int getconfs(const char *, STRBUF *);
int getconfb(const char *);
char *getconfline(void);
void closeconf(void);

#endif /* ! _CONF_H_ */

==> global-5.2.tar.gz: global-5.2/libutil/conf.h <==
/*
 * Copyright (c) 1998, 1999, 2000, 2001, 2002, 2003
 *	Tama Communications Corporation
 *
 * This file is part of GNU GLOBAL.
 *
 * GNU GLOBAL is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * GNU GLOBAL is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 */

#ifndef _CONF_H_
#define _CONF_H_

#include "strbuf.h"
/*
 * Access library for gtags.conf (.globalrc).
 * File format is a subset of XXXcap (termcap, printcap) file.
 */
#define GTAGSCONF       "/etc/gtags.conf"
#define OLD_GTAGSCONF   "/etc/global.conf"	/* for compatibility */
#define DEBIANCONF      "/etc/gtags/gtags.conf"
#define OLD_DEBIANCONF  "/etc/gtags/global.conf"/* for compatibility */
#define GTAGSRC 	".globalrc"
#ifdef __DJGPP__
#define DOS_GTAGSRC	"_globalrc"
#endif
#define DEFAULTLABEL    "default"

void openconf(void);
int getconfn(const char *, int *);
int getconfs(const char *, STRBUF *);
int getconfb(const char *);
const char *getconfline(void);
void closeconf(void);

#endif /* ! _CONF_H_ */
